@@ -23,7 +23,7 @@
 #define BITS_PER_INT (sizeof(unsigned int) * 8)
 
 
-static __inline__ uint32_t rol(uint32_t arg, int shift)
+static inline uint32_t rol(uint32_t arg, int shift)
 {
 	arg &= 0xffffffff; /* for 64 bit machines */
 	return (arg << shift) | (arg >> (32 - shift));
@@ -76,7 +76,7 @@ static unsigned int addBit(unsigned int *bitmap,
 	}
 }
 
-static int _addHash(dirCache_t *cache, unsigned int hash, int checkOnly)
+static int mt_addHash(dirCache_t *cache, unsigned int hash, int checkOnly)
 {
 	return
 		addBit(cache->bm0, hash, checkOnly) &&
@@ -87,7 +87,7 @@ static int _addHash(dirCache_t *cache, unsigned int hash, int checkOnly)
 
 static void addNameToHash(dirCache_t *cache, wchar_t *name)
 {
-	_addHash(cache, calcHash(name), 0);
+	mt_addHash(cache, calcHash(name), 0);
 }
 
 static void hashDce(dirCache_t *cache, dirCacheEntry_t *dce)
@@ -104,7 +104,7 @@ int isHashed(dirCache_t *cache, wchar_t *name)
 {
 	int ret;
 
-	ret =  _addHash(cache, calcHash(name), 1);
+	ret =  mt_addHash(cache, calcHash(name), 1);
 	return ret;
 }
 
@@ -118,9 +118,10 @@ int growDirCache(dirCache_t *cache, unsigned int slot)
 	if( cache->nr_entries <= slot) {
 		unsigned int i;
 
-		cache->entries = realloc(cache->entries,
-					 (slot+1) * 2 *
-					 sizeof(dirCacheEntry_t *));
+		cache->entries =
+			(dirCacheEntry_t **) realloc(cache->entries,
+						     (slot+1) * 2 *
+						     sizeof(dirCacheEntry_t *));
 		if(!cache->entries)
 			return -1;
 		for(i= cache->nr_entries; i < (slot+1) * 2; i++) {
