@@ -17,14 +17,12 @@
 
 #include "sysincludes.h"
 #include "stream.h"
-#include "fsP.h"
 #include "llong.h"
 #include "mtools.h"
 
 #if 1
 const mt_off_t max_off_t_31 = MAX_OFF_T_B(31); /* Floppyd */
 static const mt_off_t max_off_t_32 = MAX_OFF_T_B(32); /* Directory */
-static const mt_size_t max_size_t_32 = MAX_SIZE_T_B(32);
 const mt_off_t max_off_t_41 = MAX_OFF_T_B(41); /* SCSI */
 const mt_off_t max_off_t_seek = MAX_OFF_T_B(SEEK_BITS); /* SCSI */
 #else
@@ -37,10 +35,6 @@ int fileTooBig(mt_off_t off) {
 	return (off & ~max_off_t_32) != 0;
 }
 
-int fileSizeTooBig(mt_size_t siz) {
-	return (siz & ~max_size_t_32) != 0;
-}
-
 /* truncMtOffToOff */
 off_t truncBytes32(mt_off_t off)
 {
@@ -62,37 +56,25 @@ uint32_t truncMtOffTo32u(mt_off_t off)
 
 uint32_t truncSizeTo32u(size_t siz)
 {
-	if (fileSizeTooBig(siz)) {
+	if (siz > UINT32_MAX) {
 		fprintf(stderr, "Internal error, size too big\n");
 		exit(1);
 	}
 	return (uint32_t) siz;
 }
 
-ssize_t truncOffToSsize(off_t off)
+#if SIZEOF_MT_OFF_T == 4
+mt_off_t to_mt_off_t(uint32_t off)
 {
-	if (off > SSIZE_MAX) {
-		fprintf(stderr, "Internal error, offset out of range\n");
+	if(off > UINT32_MAX >> 1) {
+		fprintf(stderr, "File size/pos %d too big for this platform\n",
+			off);
 		exit(1);
 	}
-	return (ssize_t) off;
+	return (mt_off_t) off;
 }
+#endif
 
-size_t truncOffToSize(off_t off)
-{
-	if (off > (off_t)SIZE_MAX || off < 0) {
-		fprintf(stderr, "Internal error, offset out of range\n");
-		exit(1);
-	}
-	return (size_t) off;
-}
-
-
-mt_off_t sectorsToBytes(Stream_t *Stream, uint32_t off)
-{
-	DeclareThis(Fs_t);
-	return (mt_off_t) off << This->sectorShift;
-}
 
 #if defined HAVE_LLSEEK
 # ifndef HAVE_LLSEEK_PROTOTYPE
@@ -106,7 +88,6 @@ extern long long lseek64 (int fd, long long offset, int origin);
 # endif
 #endif
 
-
 int mt_lseek(int fd, mt_off_t where, int whence)
 {
 #if defined HAVE_LSEEK64
