@@ -241,7 +241,7 @@ static int calc_fat_len(Fs_t *Fs, uint32_t tot_sectors)
 
 #ifdef DEBUG
 	fprintf(stderr, "Fat start=%d\n", Fs->fat_start);
-	fprintf(stderr, "tot_sectors=%lu\n", tot_sectors);
+	fprintf(stderr, "tot_sectors=%"PRIu32"\n", tot_sectors);
 	fprintf(stderr, "dir_len=%d\n", Fs->dir_len);
 #endif
 	Fs->fat_len = 0;
@@ -259,7 +259,7 @@ static int calc_fat_len(Fs_t *Fs, uint32_t tot_sectors)
 		rem_sect--;
 
 #ifdef DEBUG
-	fprintf(stderr, "Rem sect=%lu\n", rem_sect);
+	fprintf(stderr, "Rem sect=%"PRIu32"\n", rem_sect);
 #endif
 
 	/* See fat_size_calculation.tex or
@@ -306,7 +306,7 @@ static int calc_fat_len(Fs_t *Fs, uint32_t tot_sectors)
 	}
 
 #ifdef DEBUG
-	fprintf(stderr, "Numerator=%lu denominator=%lu\n",
+	fprintf(stderr, "Numerator=%"PRIu32" denominator=%"PRIu32"\n",
 		numerator, denominator);
 #endif
 
@@ -332,7 +332,7 @@ static void check_fs_params_and_set_fat(Fs_t *Fs, uint32_t tot_sectors)
 
 #ifdef DEBUG
 	fprintf(stderr, "Num_clus=%d fat_len=%d nybbles=%d\n",
-		Fs->num_clus, Fs->fat_len, fat_nybbles);
+		Fs->num_clus, Fs->fat_len, Fs->fat_bits / 4);
 #endif
 
 #ifdef HAVE_ASSERT_H
@@ -1266,6 +1266,12 @@ void mformat(int argc, char **argv, int dummy UNUSEDP)
 
 	/* create the image file if needed */
 	if (create) {
+		/* Write at end of image file to create it. It is safe
+		 * to re-use boot and zero out sector's memory buffer
+		 * for this, as in the case of create=1, there is no
+		 * old boot sector, and it will not have been read by
+		 * the PREADS in the devices loop above */
+		memset(boot.characters, '\0', Fs->sector_size);
 		PWRITES(Fs->head.Next, &boot.characters,
 			sectorsToBytes(Fs, tot_sectors-1),
 			Fs->sector_size);
