@@ -8,8 +8,10 @@
 Stream_t *OpenImage(struct device *out_dev, struct device *dev,
 		    const char *name, int mode, char *errmsg,
 		    int flags, int lockMode,
-		    mt_size_t *maxSize, int *geomFailureP
+		    mt_off_t *maxSize, int *geomFailureP,
 #ifdef USE_XDF
-		    , struct xdf_info *xdf_info
+		    struct xdf_info *xdf_info
+#else
+		    void *dummy
 #endif
 		    );
